@@ -1,14 +1,10 @@
-### nPairs.R
-###------------------------------------------------------------------------
-### What: Number of variable pairs - code
-### $Id$
-### Time-stamp: <2008-12-30 18:29:58 ggorjan>
-###------------------------------------------------------------------------
+## Number of variable pairs
 
 nPairs <- function(x, margin=FALSE, names=TRUE, abbrev=TRUE, ...)
 {
-  ## --- Setup ---
-  if(!is.data.frame(x) & !is.matrix(x)) stop("'x' must be a data.frame or a matrix")
+  ## Setup
+  if(!is.data.frame(x) & !is.matrix(x))
+    stop("'x' must be a data.frame or a matrix")
   k <- ncol(x)
   if(!margin) {
     ret <- matrix(nrow=k, ncol=k)
@@ -16,7 +12,7 @@ nPairs <- function(x, margin=FALSE, names=TRUE, abbrev=TRUE, ...)
     ret <- matrix(nrow=k, ncol=k + 1)
   }
 
-  ## --- Count ---
+  ## Count
   diag(ret)[1:k] <- apply(X=x, MARGIN=2, FUN=function(x) sum(!is.na(x)))
   for(i in 1:k) {
     for(j in i:k) {
@@ -30,8 +26,8 @@ nPairs <- function(x, margin=FALSE, names=TRUE, abbrev=TRUE, ...)
       }
     }
   }
-  
-  ## --- Names ---
+
+  ## Names
   if(names) {
     tmp <- colnames(x)
     if(abbrev) tmp <- as.character(abbreviate(tmp, ...))
@@ -58,6 +54,3 @@ summary.nPairs <- function(object, ...)
   dimnames(ret) <- dimnames(object)
   ret
 }
-
-###------------------------------------------------------------------------
-### nPairs.R ends here
